
# GITHUB ISSUES REPORT FOR microsoft/debugpy


Generated on 2022-03-15 using: stale=30, all=0


Only showing items that are new to report in past 1 day(s)


=================================================================


## FOR ISSUES THAT ARE NOT MARKED AS BUGS:


### Issues in debugpy that have newer comments from 3rd party 1 day(s) or more after last team response:


\* [174](https://github.com/microsoft/debugpy/issues/174 "Support column breakpoints"): 3rd party responded 881 days ago but team last responded 882 days ago

\* [204](https://github.com/microsoft/debugpy/issues/204 "Performance in attached and detached state is similar."): 3rd party responded 1008 days ago but team last responded 1008 days ago

\* [309](https://github.com/microsoft/debugpy/issues/309 "Add test for &quot;qt&quot; debug config property"): 3rd party responded 629 days ago but team last responded 629 days ago

\* [461](https://github.com/microsoft/debugpy/issues/461 "Rework template settings"): 3rd party responded 495 days ago but team last responded 495 days ago

\* [480](https://github.com/microsoft/debugpy/issues/480 "Error message for embedded python adapter timeout"): 3rd party responded 476 days ago but team last responded 476 days ago

\* [517](https://github.com/microsoft/debugpy/issues/517 "Python debugger extension support"): 3rd party responded 434 days ago but team last responded 434 days ago

\* [561](https://github.com/microsoft/debugpy/issues/561 "Treat mapped files as my code"): 3rd party responded 368 days ago but team last responded 368 days ago

\* [623](https://github.com/microsoft/debugpy/issues/623 "Improve logging of loading of native library (used to set tracing to all threads)"): 3rd party responded 284 days ago but team last responded 285 days ago

\* [750](https://github.com/microsoft/debugpy/issues/750 "Support PEP 582 (__pypackages__) for just-my-code and user-uncaught exceptions"): 3rd party responded 155 days ago but team last responded 155 days ago

\* [783](https://github.com/microsoft/debugpy/issues/783 "use vscode to remote debug python program with tmux session "): 3rd party responded 98 days ago but team last responded 99 days ago

\* [818](https://github.com/microsoft/debugpy/issues/818 "Could not debug remote code with dataloaders which has num_workers>0"): 3rd party responded 85 days ago but team last responded 85 days ago
